//
// PovRay scene file for a set of simple coins
//
// Author:   Hj. Malthaner
// Email:    hansjoerg.malthaner@gmx.de
// Creation: 07-Dec-09
// Update:   08-Dec-09
//
// Web:      http://opengameart.org/users/varkalandar
//
// This file is available under the GNU general
// public license v2 or newer.
//
// http://www.gnu.org/licenses/gpl-2.0.html
//
  
#declare Cam1 = camera {
	orthographic
	location < 2.5, 2.5*0.82, 2.5 >*1.4
	look_at < 0, 0, 0 >
}

camera { 
	Cam1 
}

light_source { 
	< 2.5*20, 100, 2.5*10 >
	color rgb < 1, 1, 1 > 
}

// sky sphere

sphere {
	<0,0,0>, 10000

	hollow

	pigment {
        color rgb 1
	}
}	

#declare FM = 3.0;

#declare FLOOR = box {
	<-1*FM, -0.0, -1*FM>,
	<1*FM, -0.3, 1*FM>

	texture {
		pigment{
                
			marble
			turbulence 0.7
			scale 0.02
            
			// Earth/Sand
			color_map{
				[0.0 color <35/255, 30/255, 45/255>] 
				[0.2 color <95/255, 80/255, 50/255>] 
				[0.75 color <110/255, 95/255, 60/255>]
				[0.85 color <155/255, 140/255, 80/255>]
				[1.0 color <180/255, 180/255, 180/255>]
			}

			quick_color rgb 1
		}

		normal {
			bumps 0.2
			scale 0.02                
		}

		finish {
			ambient 0.2
		}
	}
}


#declare T_SILVER_METAL = texture
{
        pigment {
                color rgb <0.66, 0.63, 0.6>
                quick_color 0
        }
        
        normal {
                // bumps 0.05
                // scale 1
                granite 0.04
                scale 0.4
        }
        finish {
                brilliance 1.1
                ambient 0.15
                diffuse 0.7
        
                specular 1.2
                roughness 0.18
                reflection 0.15
                metallic
        }

}


#declare T_GOLD_METAL = texture {
        T_SILVER_METAL
                
        pigment {
                color rgb <0.59, 0.51, 0.2>
                quick_color 0
        }
}
                            
#declare T_COPPER_METAL = texture {
        T_SILVER_METAL
                
        pigment {
                color rgb <0.63, 0.32, 0.15>
                quick_color 0
        }
}
                            

#declare COIN_BODY = union {

        difference {
                cylinder {
                        <0, 0, -0.1>, <0, 0, 0.1>, 1 
                }
        
                cylinder {
                        <0, 0, -0.2>, <0, 0, -0.077>, 0.88 
                }
        
                cylinder {
                        <0, 0, 0.2>, <0, 0, 0.077>, 0.88 
                }
                
                #declare n=0;
                
                #while(n<48)
                        cylinder {
                                <0, 0, -0.3>, <0, 0, 0.3>, 0.04 
                                translate <0, 1.03, 0>
                                rotate <0, 0, n*360/48>
                        }
                        
                
                        #declare n=n+1;
                #end
        
        }

        text {
                ttf "times.ttf" "H" 0.2, 0
                scale 0.13
                rotate <0, 180, 0>
                translate <0.08, 0.67, 0.1>
        }

        text {
                ttf "times.ttf" "2009" 0.2, 0
                scale 0.15
                rotate <0, 180, 0>
                translate <0.12, -0.75, 0.1>
        }
}

        
#declare COIN_50 = union {
        object {
                COIN_BODY
        }
        
        text {
                ttf "times.ttf" "50" 0.2, 0
                scale 1.3
                rotate <0, 180, 0>
                translate <0.55, -0.4, 0.1>
        }
        
        
        texture {
                T_GOLD_METAL
        }
        
        translate <0, 1, 0>

}

#declare COIN_10 = union {
        object {
                COIN_BODY
        }
        
        text {
                ttf "times.ttf" "10" 0.2, 0
                scale 1.3
                rotate <0, 180, 0>
                translate <0.52, -0.4, 0.1>
        }
        
        
        texture {
                T_COPPER_METAL
        }
        
        translate <0, 1, 0>

}

#declare COIN_1 = union {
        object {
                COIN_BODY
        }
        
        text {
                ttf "times.ttf" "1" 0.2, 0
                scale 1.5
                rotate <0, 180, 0>
                translate <0.23, -0.5, 0.1>
        }
        
        
        texture {
                T_SILVER_METAL
        }
        
        translate <0, 1, 0>

}

union {

	object {
		FLOOR
	}

	object {
	        COIN_10
	        scale <0.9, 0.9, 0.6>
	        rotate <0, 7, 0>
	        translate <1, 0, -1>
	}

	object {
	        COIN_50
	        scale <1, 1, 0.7>
	        rotate <0, 7, 0>
	}

	object {
	        COIN_1
	        scale <1.1, 1.1, 0.8>
	        rotate <0, 7, 0>
	        translate <-1, 0, 1>
	}

	translate <0, -1, 0>
}